# diwork

**DI**wo**R**k - directory work. `diwork` is a continuation of [folder_work](https://github.com/The220th/folder_work).

# Install

``` bash
pip3 install diwork
```

# Usage

``` bash
> diwork help
```
